@@ -21,6 +21,7 @@
 
 namespace py = pybind11;
 
+// sketches
 void init_hll(py::module& m);
 void init_kll(py::module& m);
 void init_fi(py::module& m);
@@ -29,10 +30,13 @@ void init_theta(py::module& m);
 void init_vo(py::module& m);
 void init_req(py::module& m);
 void init_quantiles(py::module& m);
-void init_kolmogorov_smirnov(py::module& m);
 void init_vector_of_kll(py::module& m);
 
-PYBIND11_MODULE(datasketches, m) {
+// supporting objects
+void init_kolmogorov_smirnov(py::module& m);
+void init_serde(py::module& m);
+
+PYBIND11_MODULE(_datasketches, m) {
   init_hll(m);
   init_kll(m);
   init_fi(m);
@@ -41,6 +45,8 @@ PYBIND11_MODULE(datasketches, m) {
   init_vo(m);
   init_req(m);
   init_quantiles(m);
-  init_kolmogorov_smirnov(m);
   init_vector_of_kll(m);
+
+  init_kolmogorov_smirnov(m);
+  init_serde(m);
 }
